.onAttach <- function(libname, pkgname) {
  cite_info <- utils::citation(pkgname)
  cite_info <- "Jiangshan Lai, Yan He, Mi Hou, Aiying Zhang, Gang Wang, Lingfeng Mao, 2025.Evaluating the relative importance of phylogeny and predictors in Phylogenetic Generalized Linear Models using the phylolm.hp R package, Plant Diversity, 47(5):709-717"
  packageStartupMessage("Thank you for using this package! If you use this package in your research, please cite the following references \n")
  packageStartupMessage(cite_info)
}
